pub struct UdpStream<const BUF_SIZE: usize> { /* private fields */ }Expand description
A non-blocking async UdpSocket with ability to recv_from via next and send_to via push.
BUF_SIZE
Messages received via [UdpStream::next] will be provided as an array of bytes of length
BUF_SIZE. This is a generic const to allow avoid us having to allocate a 65k buffer on each
call to next in order to cover the max possible UDP datagram size.
It is your responsibility to ensure that BUF_SIZE is large enough to hold the largest UDP
datagram your protocol expects; if it is smaller than the incoming datagram size, the datagram
will be truncated in the output from next. You cannot rely on the returned bytes_read value
to indicate truncation as this will also be set to the buffer length, not the full size of the
truncated message (this is the underlying behaviour of the libc call recv_from).
Note
- This does NOT have exclusive access to the bound port. If you want to guarantee that
no other processes bind to the same socket vote thumbs up on issue #22 TODO: implement
bind_exclusiveetc.)